@@ -26,8 +26,6 @@ require("sdk/preferences/service").set(name, "off");
 const jsAnalyzer = require("js_checker/js_checker");
 
 const widgets = require("sdk/widget");
-const persistentpanel = require("persistentpanel/persistentpanel");
-const betterWidget = require("persistentpanel/better-widget");
 const panel = require("sdk/panel");
 
 const pageWorker = require("sdk/page-worker");
